@@ -10,7 +10,7 @@ from distutils.msvccompiler.
 """
 
 #
-# Copyright (c) 2001 - 2014 The SCons Foundation
+# Copyright (c) 2001 - 2015 The SCons Foundation
 #
 # Permission is hereby granted, free of charge, to any person obtaining
 # a copy of this software and associated documentation files (the
@@ -33,7 +33,7 @@ from distutils.msvccompiler.
 #
 from __future__ import division
 
-__revision__ = "src/engine/SCons/Defaults.py  2014/09/27 12:51:43 garyo"
+__revision__ = "src/engine/SCons/Defaults.py rel_2.3.5:3329:275e75118ad4 2015/06/20 11:18:26 bdbaddog"
 
 
 import os
@@ -198,11 +198,10 @@ def copy_func(dest, src, symlinks=True):
             shutil.copy2(file, dest)
         return 0
     elif os.path.islink(src):
-        linkto = os.readlink(src)
         if symlinks:
-            return os.symlink(linkto, dest)
+            return os.symlink(os.readlink(src), dest)
         else:
-            return copy_func(dest, linkto, symlinks)
+            return copy_func(dest, os.path.realpath(src))
     elif os.path.isfile(src):
         return shutil.copy2(src, dest)
     else:
