@@ -8,7 +8,7 @@ selection method.
 """
 
 #
-# Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014 The SCons Foundation
+# Copyright (c) 2001 - 2015 The SCons Foundation
 #
 # Permission is hereby granted, free of charge, to any person obtaining
 # a copy of this software and associated documentation files (the
@@ -30,7 +30,7 @@ selection method.
 # WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 #
 
-__revision__ = "src/engine/SCons/Tool/aixcc.py  2014/03/02 14:18:15 garyo"
+__revision__ = "src/engine/SCons/Tool/aixcc.py rel_2.3.5:3329:275e75118ad4 2015/06/20 11:18:26 bdbaddog"
 
 import os.path
 
@@ -42,25 +42,25 @@ packages = ['vac.C', 'ibmcxx.cmp']
 
 def get_xlc(env):
     xlc = env.get('CC', 'xlc')
-    xlc_r = env.get('SHCC', 'xlc_r')
-    return SCons.Platform.aix.get_xlc(env, xlc, xlc_r, packages)
+    return SCons.Platform.aix.get_xlc(env, xlc, packages)
 
 def generate(env):
     """Add Builders and construction variables for xlc / Visual Age
     suite to an Environment."""
-    path, _cc, _shcc, version = get_xlc(env)
-    if path:
+    path, _cc, version = get_xlc(env)
+    if path and _cc:
         _cc = os.path.join(path, _cc)
-        _shcc = os.path.join(path, _shcc)
+
+    if 'CC' not in env:
+        env['CC'] = _cc
 
     cc.generate(env)
 
-    env['CC'] = _cc
-    env['SHCC'] = _shcc
-    env['CCVERSION'] = version
+    if version:
+        env['CCVERSION'] = version
 
 def exists(env):
-    path, _cc, _shcc, version = get_xlc(env)
+    path, _cc, version = get_xlc(env)
     if path and _cc:
         xlc = os.path.join(path, _cc)
         if os.path.exists(xlc):
